#include "inet.h"
#include "dvm.h"

extern          FILE    *jfp;

/*
 * Function Name : receive_data_to_file()
 *
 * Description   : Receive data via socket and write received data on 
 *                 the file that is given by an argument.
 *
 * Input(s)      : sockfd  - socket file descriptor
 *                 tofname - the place where data will be written
 *
 * Output(s)     : 1 - Success , 0 - Error
 *
 * Programmed by : Ilkyeun Ra, Syracuse University
 *
*/
receive_data_to_file(sockfd,tofname)
int  sockfd;
char *tofname;
{
     int tofd, nread, nwrite,n;
     char buf[BUFFSIZE];
     
     /*
      * Create a file that will be written
     */
     if ( (tofd = creat(tofname,0666)) == -1) {
           err_ret("VDCE: can't creat a file \n");
	   return(0);
     }

     /*
      * read a data from socket and write a data 
      */
     while ( (nread = read(sockfd, buf, sizeof(buf)))  != 0 ) {
          if (nread == -1) {
	      close(sockfd);
	      err_ret("VDCE: Error in reading data via socket\n");
	      return(0);
	  }
	  nwrite = 0;
	  do {
	     if ((n=write(tofd,&buf[nwrite],nread-nwrite)) == -1) {
		close(tofd); 
		close(sockfd);
	        fprintf(jfp,"VDCE: Error in writing data to the file %s\n",
			tofname);
		return(0);
	     }
	     nwrite += n;
	  }   while (nwrite < nread);
     } /* end of while */

     close(tofd);
     return(1); 

}

/*
 * Function Name : send_data_from_file()
 *
 * Description   : reading result data from a file and write transferring  
 *                 data on the socket 
 *
 * Input(s)      : sockfd  - socket file descriptor
 *                 fromfname - result file name
 *
 * Output(s)     : 1 - Success , 0 - Error
*/
send_data_from_file(sockfd,fromfname)
int  sockfd;
char *fromfname;
{
     int fromfd, nread, nwrite,n;
     char buf[BUFFSIZE];
     
     /*
      * Create a file that will be written
     */
     if ( (fromfd = open(fromfname,0666)) == -1) {
           err_ret("VDCE: can't open a file \n");
	   return(0);
     }

     /*
      * read a data from socket and write a data 
      */
     while ( (nread = read(fromfd, buf, sizeof(buf))) != 0 ) {
          if (nread == -1) {
	      close(fromfd);
	      err_ret("VDCE: Error in reading result data \n");
	      return(0);
	  }
	  nwrite = 0;
	  do {
	     if ( (n=write(sockfd,&buf[nwrite],nread-nwrite)) == -1) {
	        fprintf(jfp,"VDCE: Error in writing data to a socekt %s\n",
			fromfname);
		close(fromfd); 
		close(sockfd);
		return(0);
	     }
	     nwrite += n;
	  }   while (nwrite < nread);
	  sleep(1); /* fro sync */
     } /* end of while */

     close(fromfd);
     return(1); 

}
